@@ -1,5 +1,5 @@
 from rich.prompt import Confirm
-from cmdcheatsheet.config.core import set_config_to_default
+from .core import set_config_to_default
 from cmdcheatsheet.shared.models import CommandDetails
 
 
